@@ -4,7 +4,7 @@ use 5.008000;
 use strict;
 use warnings;
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 our $sensitive_modules;
 
@@ -19,7 +19,7 @@ our $inc_sniffer = sub {
     $pkg =~ s/\.pm$//;
     $pkg =~ s{/+}{::}g;
     # For efficiency purposes, skip module unless it's one of the special case sensitive packages flagged to load case-sensitively.
-    $sensitive_modules->{$pkg} or return undef;
+    $sensitive_modules->{$pkg} or $sensitive_modules->{'-all'} or return undef;
 
     # Skip the directories before me since they've already been tried (and obviously didn't find the file already or else we wouldn't be here)
     my $keep = 0;
@@ -154,6 +154,9 @@ Module::Case - Case sensitive module loading.
     # Now load only the lowercase file
     use config;
 
+    # Or to enforce all modules to be case-sensitive
+    use Module::Case '-all';
+
 =head1 DESCRIPTION
 
 This module was created to alleviate the problems caused by
@@ -181,7 +184,7 @@ any file that smells like the module wishing to load.
 
 If the specified module doesn't exactly match the case of how it was
 requested, then the "require" or "use" will die with an error
-instead of gleefully loading any case-insensitively matching module.
+instead of gleefully loading any file matching case-insensitively.
 
 =head1 CAVEATS
 
@@ -195,7 +198,7 @@ matching what has been flagged for sensitively. For example:
 
 Then the contents of "Exact/Module/Name.pm" must contain
 "package Exact::Module::Name" somewhere in the pm file
-or else it should fail to load.
+or else it will fail to load.
 
 If there are multiple different modules that match case-insensitvely
 and you wish to load more than one of these, then it would be safer
